#
# spec file for package python-flower
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
Name:           python-flower
Version:        0.9.3
Release:        bp155.2.13
Summary:        A web frontend for monitoring and administrating Celery clusters
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/mher/flower
Source:         https://files.pythonhosted.org/packages/source/f/flower/flower-%{version}.tar.gz
# Tornado 5+ update blocked by salt, so backport the missing piece
Patch0:         backport_run_in_executor.patch
BuildRequires:  %{python_module Babel >= 1.0}
BuildRequires:  %{python_module celery >= 3.1.0}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module kombu}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tornado >= 4.2.0}
BuildRequires:  fdupes
Requires:       python-Babel >= 1.0
Requires:       python-celery >= 3.1.0
Requires:       python-certifi
Requires:       python-pytz
Requires:       python-tornado >= 4.2.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-futures
%endif
%ifpython2
Requires:       python-futures
%endif
%python_subpackages

%description
Flower is a web based tool for monitoring and administrating Celery clusters.

%prep
%setup -q -n flower-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/flower
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative flower

%postun
%python_uninstall_alternative flower

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/flower

%changelog
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Nov 15 2019 Matej Cepl <mcepl@suse.com>
- Use %%pytest instead of python setup.py test combination.
* Fri Mar 22 2019 John Vandenberg <jayvdb@gmail.com>
- Remove no longer needed remove-faulty-test.patch
- Use backport_run_in_executor.patch to be compatible with Tornado 4
- Increase minimum dependencies for celery >= 3.1.0 and Tornado >= 4.2.0
- Update to v0.9.3
  * Fix numeric sort and sort ordering
  * Support filtering tasks by received time
  * Fix "not JSON serializable" `TypeError` for /api/task/info
  * Fixed Auth redirect when -url_prefix is given
  * OpenAPI 2.0 swagger spec initial commit
  * Update tasks datatable to use POST method
  * Fix hanging issues with tornado 5.0.0
  * Add 'signal' query parameter to endpoint /api/task/revoke
  * Use parse_version instead of tuple comparisons
  * /tasks endpoint fails with 500
  * Add links for parent and root jobs
  * Make dropdown font colour white instead of grey
  * Fix incorrect response body
  * Removed some legacy code for Python 2.6
  * Document the GetQueueLengths API endpoint
  * Enable broker support for redis+socket connections
  * Fix docs for default inspect_timeout value
  * Fix typo in Google OAuth 2 redirect uri env variable
  * Upgrade tornado
  * Fix the out-dated doc link in Worker.html
  * Declare futures dependency using environment markers
  * Fixing GitHub OAuth callback handling
  * Correct spelling error
  * Correct spelling and grammatical errors
  * Switch away from Google+ OAuth2
  * restrict release dependencies with version upper-bound
- from v0.9.2
  * Add logout button
  * Fix a bug in humanizing timestamps on the tasks page
  * Handle errors in custom format_task functions
  * Pending tasks don't have a worker
  * Fix result encoding
  * Removed 500px height limitation
  * Do not show debug information on 500 error
  * Fixed Python 3 mistake in Github Login Handler
  * Support environment variables in tornado 4.2.0 and >=4.3
  * Fix XSS on tasks page
  * Enable cross-origin websockets
  * Fix bugreport
  * Resolve relative config file names
  * Fix broker api validation
  * Loosen broker api validation
  * Replace websokets with ajax
  * Fix bug in tasks page template
  * Fix celery version comparsion
  * Refactor version comparision
  * Fixes in config documents
  * Fix invalid URL used for datatable query
  * Use redis as default broker
  * Update dashboard counters on worker table updates
  * Move shut down group button to worker page
  * Update navbar title
  * Add a script for calling tasks
  * Add a link to worker name
  * Remove active task start time from worker page
  * Fix py3 json serialization
  * Fix Error 500 because task.worker is None
  * HTML escape task args
  * Disable broker cert verification
  * Enable all tasks columns with --tasks-options=all
  * Add runtime to default tasks columns
  * Document --tasks-columns=all
  * Refactor redis broker
  * Support CELERY_QUEUES option
  * Remove rabbitmq-plugins enable warning
  * Fix broken link to celery configuration document
- from v0.9.1
  * Improve envvar handling
  * By default update worker cache
  * Fix task sorting for py3
  * Fix missing workername
  * Fix monitor tab problem of missing graphs
- from v0.9.0
  * workers can be sorted and filtered
  * tasks can be sorted, filtered by name, state, worker, runtime, etc.
  * tasks columns can be reordered and customized
  * tasks columns for worker, retries, revoked, expires, eta, etc.
  * pagination of tasks
  * GitHub Auth support
  - -max_workers option for limiting the number of workers
  - -unix_socket option for running with unix socket
  * bug fixes
* Wed Feb 20 2019 John Vandenberg <jayvdb@gmail.com>
- Remove flower-test_control.diff merged upstream
- Add remove-faulty-test.patch for useless test case
- Add more missing runtime dependencies Babel & pytz not covered by tests
- Update to v0.8.4
  * Fix /api/tasks #460
  * Disable tornado access logs
  * Fix #462
  * Improve error handling for unsupported brokers
  * Make sure Babel is at least 1.0
  * Updated a test to use assert_called_once_with
  * Updating readme for OAuth
  * The viewer tasks, has been enhanced to display the key word arguments
    and arguments showing now indented way information
  * Add logging.NullHandler backport #501
  * Fix github auth python3 support #498
  * Use timezone from celery settings if configured.
  * Add option `unix_socket`, deploy on docker and expose the sock file
  * Discover tests in tests/*.py
  * Fix bug, `events.Task.as_dict` is new in `Celery 3.1.7`
  * events.Task.as_dict is new in Celery 3.1.7
  * Refactor /api/tasks/ #515
  * Use pprint instead of ast #491
  * Define CELERY_ACCEPT_CONTENT for examples
  * Fix task searching #480
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Update to use single spec for Python 2 & 3 support
- Add missing build dependency certifi
- Add missing runtime dependencies
- Remove unnecessary build dependency python-devel
- Use %%license
* Wed Mar  2 2016 jgleissner@suse.com
- fixed one of the unit tests that fails with newer python-mock
* Tue Dec 15 2015 jgleissner@suse.com
- Initial package
